@@ -16,6 +16,11 @@ class EntityStatus(IntEnum):
     DISABLED = 1
 
 
+class Permission(IntEnum):
+    READ_ONLY = 2
+    READ_WRITE = 3
+
+
 class Priority(IntEnum):
     NOT_CLASSIFIED = 0
     INFORMATION = 1
